@@ -25,7 +25,7 @@ use Carp;
 
 require Exporter;
 
-$VERSION = "1.76";
+$VERSION = "1.78";
 
 require DynaLoader;
 
@@ -511,6 +511,7 @@ sub output_as_chars { shift->{XML_LIBXSLT_STYLESHEET}->_output_string($_[0],2) }
 sub output_fh { shift->{XML_LIBXSLT_STYLESHEET}->output_fh(@_) }
 sub output_file { shift->{XML_LIBXSLT_STYLESHEET}->output_file(@_) }
 sub media_type { shift->{XML_LIBXSLT_STYLESHEET}->media_type(@_) }
+sub output_method { shift->{XML_LIBXSLT_STYLESHEET}->output_method(@_) }
 sub output_encoding { shift->{XML_LIBXSLT_STYLESHEET}->output_encoding(@_) }
 
 1;
@@ -622,7 +623,7 @@ __END__
 
 =head1 NAME
 
-XML::LibXSLT - Interface to the gnome libxslt library
+XML::LibXSLT - Interface to the GNOME libxslt library
 
 =head1 SYNOPSIS
 
@@ -642,7 +643,7 @@ XML::LibXSLT - Interface to the gnome libxslt library
 
 =head1 DESCRIPTION
 
-This module is an interface to the gnome project's libxslt. This is an
+This module is an interface to the GNOME project's libxslt. This is an
 extremely good XSLT engine, highly compliant and also very fast. I have
 tests showing this to be more than twice as fast as Sablotron.
 
@@ -785,16 +786,20 @@ happen with one stylesheet without requiring a reparse.
 
 =item transform(doc, %params)
 
-  my $results = $stylesheet->transform($doc, foo => "value);
+  my $results = $stylesheet->transform($doc, foo => "'bar'");
   print $stylesheet->output_as_bytes($results);
 
 Transforms the passed in XML::LibXML::Document object, and returns a
 new XML::LibXML::Document. Extra hash entries are used as parameters.
-See output_string
+Be sure to keep in mind the caveat with regard to quotes explained in
+the section on L</"Parameters"> below.
 
 =item transform_file(filename, %params)
 
-  my $results = $stylesheet->transform_file($filename, bar => "value");
+  my $results = $stylesheet->transform_file($filename, bar => "'baz'");
+
+Note the string parameter caveat, detailed in the section on
+L</"Parameters"> below.
 
 =item output_as_bytes(result)
 
@@ -834,12 +839,27 @@ Outputs the result to the file named in C<$filename>.
 
 Returns the output encoding of the results. Defaults to "UTF-8".
 
+=item output_method()
+
+Returns the value of the C<method> attribute from C<xsl:output>
+(usually C<xml>, C<html> or C<text>). If this attribute is
+unspecified, the default value is initially C<xml>. If the
+L<transform> method is used to produce an HTML document, as per the
+L<XSLT spec|http://www.w3.org/TR/xslt#output>, the default value will
+change to C<html>. To override this behavior completely, supply an
+C<xsl:output> element in the stylesheet source document.
+
 =item media_type()
 
-Returns the output media_type of the results. Defaults to "text/html".
+Returns the value of the C<media-type> attribute from
+C<xsl:output>. If this attribute is unspecified, the default media
+type is initially C<text/xml>. This default changes to C<text/html>
+under the same conditions as L<output_method>.
 
 =back
 
+=cut
+
 =head1 Parameters
 
 LibXSLT expects parameters in XPath format. That is, if you wish to pass
